@@ -179,7 +179,7 @@ signalHandler(int /* signal */)
 {
     // Avoid this happening more than once across threads
 
-    std::cerr << "signalHandler: cleaning up and exiting" << std::endl;
+    cerr << "signalHandler: cleaning up and exiting" << endl;
     cleanupMutex.lock();
     if (!cleanedUp) {
         TempDirectory::getInstance()->cleanup();
@@ -250,6 +250,13 @@ main(int argc, char **argv)
 #endif
 #endif
 
+#ifdef Q_OS_MAC
+    if (QSysInfo::MacintoshVersion > QSysInfo::MV_10_8) {
+        // Fix for OS/X 10.9 font problem
+        QFont::insertSubstitution(".Lucida Grande UI", "Lucida Grande");
+    }
+#endif
+
     SVApplication application(argc, argv);
 
     QStringList args = application.arguments();
@@ -257,7 +264,7 @@ main(int argc, char **argv)
     signal(SIGINT,  signalHandler);
     signal(SIGTERM, signalHandler);
 
-#ifndef Q_WS_WIN32
+#ifndef Q_OS_WIN32
     signal(SIGHUP,  signalHandler);
     signal(SIGQUIT, signalHandler);
 #endif
@@ -266,8 +273,8 @@ main(int argc, char **argv)
     bool oscSupport = true;
 
     if (args.contains("--help") || args.contains("-h") || args.contains("-?")) {
-        std::cerr << QApplication::tr(
-            "\nSonic Visualiser is a program for viewing and exploring audio data\nfor semantic music analysis and annotation.\n\nUsage:\n\n  %1 [--no-audio] [--no-osc] [<file> ...]\n\n  --no-audio: Do not attempt to open an audio output device\n  --no-osc: Do not provide an Open Sound Control port for remote control\n  <file>: One or more Sonic Visualiser (.sv) and audio files may be provided.\n").arg(argv[0]) << std::endl;
+        cerr << QApplication::tr(
+            "\nSonic Visualiser is a program for viewing and exploring audio data\nfor semantic music analysis and annotation.\n\nUsage:\n\n  %1 [--no-audio] [--no-osc] [<file> ...]\n\n  --no-audio: Do not attempt to open an audio output device\n  --no-osc: Do not provide an Open Sound Control port for remote control\n  <file>: One or more Sonic Visualiser (.sv) and audio files may be provided.\n").arg(argv[0]) << endl;
         exit(2);
     }
 
@@ -317,6 +324,10 @@ main(int argc, char **argv)
 
     QString language = QLocale::system().name();
 
+    settings.beginGroup("Preferences");
+    language = settings.value("locale", language).toString();
+    settings.endGroup();
+
     QTranslator qtTranslator;
     QString qtTrName = QString("qt_%1").arg(language);
     SVDEBUG << "Loading " << qtTrName << "... ";
@@ -331,7 +342,7 @@ main(int argc, char **argv)
     if (!success) {
         SVDEBUG << "Failed\nFailed to load Qt translation for locale" << endl;
     } else {
-        std::cerr << "Done" << std::endl;
+        cerr << "Done" << endl;
     }
     application.installTranslator(&qtTranslator);
 
@@ -363,14 +374,21 @@ main(int argc, char **argv)
     if (width > height * 2) width = height * 2;
 
     settings.beginGroup("MainWindow");
+
     QSize size = settings.value("size", QSize(width, height)).toSize();
     gui->resizeConstrained(size);
+
     if (settings.contains("position")) {
         QRect prevrect(settings.value("position").toPoint(), size);
         if (!(available & prevrect).isEmpty()) {
             gui->move(prevrect.topLeft());
         }
     }
+
+    if (settings.value("maximised", false).toBool()) {
+        gui->setWindowState(Qt::WindowMaximized);
+    }
+
     settings.endGroup();
     
     gui->show();
@@ -494,7 +512,7 @@ void SVApplication::handleFilepathArgument(QString path, QSplashScreen *splash){
                 haveMainModel = true;
             }
         } else {
-            std::cerr << "WARNING: Ignoring additional session file argument \"" << path << "\"" << std::endl;
+            cerr << "WARNING: Ignoring additional session file argument \"" << path << "\"" << endl;
             status = MainWindow::FileOpenSucceeded;
         }
     }
